# Commom Calibration methods for multivariate calibration

This is a Python library for designing antimicrobial agent. For more information, refer to www.chemoinfolab.com/antifungal.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install toolkit in requirements.txt.

## Ref
_1. Zhang J., Yang L. B., Tian Z. Q., Zhao W. J., Sun C. Q., Zhu L. J., Huang M. J., Guo G.*, Liang G. Y.* Large-Scale Screening of Antifungal Peptides Based on Quantitative Structure–Activity Relationship [J]. ACS Med. Chem. Lett., 2022, 13(1): 99-104. 

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[MIT](https://choosealicense.com/licenses/mit/)